summaryrefslogtreecommitdiffstats
path: root/src/gui/kdeext/RGLed.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/kdeext/RGLed.cpp')
-rw-r--r--src/gui/kdeext/RGLed.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/gui/kdeext/RGLed.cpp b/src/gui/kdeext/RGLed.cpp
index fbadb95..95772ca 100644
--- a/src/gui/kdeext/RGLed.cpp
+++ b/src/gui/kdeext/RGLed.cpp
@@ -59,7 +59,7 @@
*
* Revision 1.19 2001/08/08 14:35:12 hausmann
* - removed empty KActionCollection::childEvent
* - added tqsizeHint() and tqminimumSizeHint() methods to KLed, as advised by
* Rik in the comment in kled.h
* - removed unused mousePressEvent, mouseMoveEvent and mouseReleaseEvent
* handlers from KPassDlg
@@ -298,7 +298,7 @@ KLed::paintFlat() // paint a ROUND FLAT led lamp
brush.setColor( color );
pen.setWidth( 1 );
- color = tqcolorGroup().dark();
+ color = colorGroup().dark();
pen.setColor( color ); // Set the pen accordingly
paint.setPen( pen ); // Select pen for drawing
@@ -386,7 +386,7 @@ KLed::paintRound() // paint a ROUND RAISED led lamp
// avoid that the border can be erased by the bright spot of the LED
pen.setWidth( 1 );
- color = tqcolorGroup().dark();
+ color = colorGroup().dark();
pen.setColor( color ); // Set the pen accordingly
paint.setPen( pen ); // Select pen for drawing
brush.setStyle( Qt::NoBrush ); // Switch off the brush
@@ -509,11 +509,11 @@ KLed::paintSunken() // paint a ROUND SUNKEN led lamp
brush.setStyle( Qt::NoBrush ); // Switch off the brush
paint.setBrush( brush ); // This avoids filling of the ellipse
// Set the initial color value to tqcolorGroup().light() (bright) and start
// drawing the shadow border at 45� (45*16 = 720).
int angle = -720;
- color = tqcolorGroup().light();
+ color = colorGroup().light();
for ( int arc = 120; arc < 2880; arc += 240 )
{
@@ -713,13 +713,13 @@ KLed::off()
}
TQSize
-KLed::tqsizeHint() const
+KLed::sizeHint() const
{
return TQSize(16, 16);
}
TQSize
-KLed::tqminimumSizeHint() const
+KLed::minimumSizeHint() const
{
return TQSize(16, 16 );
}
@@ -59,7 +59,7 @@
* Revision 1.19 2001/08/08 14:35:12 hausmann
* - removed empty KActionCollection::childEvent
- * - added tqsizeHint() and tqminimumSizeHint() methods to KLed, as advised by
+ * - added sizeHint() and minimumSizeHint() methods to KLed, as advised by
* Rik in the comment in kled.h
* - removed unused mousePressEvent, mouseMoveEvent and mouseReleaseEvent
@@ -509,11 +509,11 @@ KLed::paintSunken() // paint a ROUND SUNKEN led lamp
brush.setStyle( Qt::NoBrush ); // Switch off the brush
paint.setBrush( brush ); // This avoids filling of the ellipse
- // Set the initial color value to tqcolorGroup().light() (bright) and start
+ // Set the initial color value to colorGroup().light() (bright) and start
// drawing the shadow border at 45� (45*16 = 720).
int angle = -720;